package com.fs.fastGpt.service;

import java.util.List;

import com.fs.common.core.domain.R;
import com.fs.fastGpt.domain.FastGptRole;
import com.fs.fastGpt.vo.FastGptRoleVO;
import com.fs.his.vo.OptionsVO;

/**
 * 应用Service接口
 *
 * @author fs
 * @date 2024-09-30
 */
public interface IFastGptRoleService
{
    /**
     * 查询应用
     *
     * @param roleId 应用主键
     * @return 应用
     */
    public FastGptRole selectFastGptRoleByRoleId(Long roleId);
    public R selectFastGptRoleByRoleIdTagListVO(Long roleId);

    /**
     * 查询应用列表
     *
     * @param fastGptRole 应用
     * @return 应用集合
     */
    public List<FastGptRole> selectFastGptRoleList(FastGptRole fastGptRole);

    public List<FastGptRoleVO> selectFastGptRoleListVO(FastGptRole fastGptRole);

    /**
     * 新增应用
     *
     * @param fastGptRole 应用
     * @return 结果
     */
    public int insertFastGptRole(FastGptRole fastGptRole);

    /**
     * 修改应用
     *
     * @param fastGptRole 应用
     * @return 结果
     */
    public int updateFastGptRole(FastGptRole fastGptRole);

    /**
     * 批量删除应用
     *
     * @param roleIds 需要删除的应用主键集合
     * @return 结果
     */
    public int deleteFastGptRoleByRoleIds(Long[] roleIds);

    /**
     * 删除应用信息
     *
     * @param roleId 应用主键
     * @return 结果
     */
    public int deleteFastGptRoleByRoleId(Long roleId);

    public R relieveFastGptRole(Long roleId);

    List<FastGptRole> selectAiDoctorList(FastGptRole fastgptRole);

    List<OptionsVO> selectFastGptRoleType();

    public FastGptRole selectFastGptRoleTypeByRoleId(Long roleId);
}
